/*
 * Copyright (C) 2018 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */


package android.net.ipsec.ike;


/**
 * SaProposal represents a proposed configuration to negotiate an IKE or Child SA.
 *
 * <p>SaProposal will contain cryptograhic algorithms and key generation materials for the
 * negotiation of an IKE or Child SA.
 *
 * <p>User must provide at least one valid SaProposal when they are creating a new IKE or Child SA.
 *
 * @see <a href="https://tools.ietf.org/html/rfc7296#section-3.3">RFC 7296, Internet Key Exchange
 *     Protocol Version 2 (IKEv2)</a>
 */

@SuppressWarnings({"unchecked", "deprecation", "all"})
public abstract class SaProposal {

SaProposal() { throw new RuntimeException("Stub!"); }

/**
 * Gets all proposed encryption algorithms
 *
 * @return A list of Pairs, with the IANA-defined ID for the proposed encryption algorithm as
 *     the first item, and the key length (in bits) as the second.
 */

@android.annotation.NonNull
public java.util.List<android.util.Pair<java.lang.Integer,java.lang.Integer>> getEncryptionAlgorithms() { throw new RuntimeException("Stub!"); }

/**
 * Gets all proposed integrity algorithms
 *
 * @return A list of the IANA-defined IDs for the proposed integrity algorithms
 */

@android.annotation.NonNull
public java.util.List<java.lang.Integer> getIntegrityAlgorithms() { throw new RuntimeException("Stub!"); }

/**
 * Gets all proposed Diffie-Hellman groups
 *
 * @return A list of the IANA-defined IDs for the proposed Diffie-Hellman groups
 */

@android.annotation.NonNull
public java.util.List<java.lang.Integer> getDhGroups() { throw new RuntimeException("Stub!"); }

/** @hide */

@android.annotation.NonNull
public java.lang.String toString() { throw new RuntimeException("Stub!"); }

public int hashCode() { throw new RuntimeException("Stub!"); }

public boolean equals(java.lang.Object o) { throw new RuntimeException("Stub!"); }

/** Returns supported DH groups for IKE and Child SA proposal negotiation. */

@android.annotation.NonNull
public static java.util.Set<java.lang.Integer> getSupportedDhGroups() { throw new RuntimeException("Stub!"); }

/** 1024-bit MODP Diffie-Hellman Group. */

public static final int DH_GROUP_1024_BIT_MODP = 2; // 0x2

/** 1536-bit MODP Diffie-Hellman Group. */

public static final int DH_GROUP_1536_BIT_MODP = 5; // 0x5

/** 2048-bit MODP Diffie-Hellman Group. */

public static final int DH_GROUP_2048_BIT_MODP = 14; // 0xe

/** 3072-bit MODP Diffie-Hellman Group. */

public static final int DH_GROUP_3072_BIT_MODP = 15; // 0xf

/** 4096-bit MODP Diffie-Hellman Group. */

public static final int DH_GROUP_4096_BIT_MODP = 16; // 0x10

/** Elliptic Curve Diffie-Hellman 25519. */

public static final int DH_GROUP_CURVE_25519 = 31; // 0x1f

/** None Diffie-Hellman Group. */

public static final int DH_GROUP_NONE = 0; // 0x0

/** 3DES Encryption/Ciphering Algorithm. */

public static final int ENCRYPTION_ALGORITHM_3DES = 3; // 0x3

/** AES-CBC Encryption/Ciphering Algorithm. */

public static final int ENCRYPTION_ALGORITHM_AES_CBC = 12; // 0xc

/** AES-CTR Encryption/Ciphering Algorithm. */

public static final int ENCRYPTION_ALGORITHM_AES_CTR = 13; // 0xd

/**
 * AES-GCM Authentication/Integrity + Encryption/Ciphering Algorithm with 12-octet ICV
 * (truncation).
 */

public static final int ENCRYPTION_ALGORITHM_AES_GCM_12 = 19; // 0x13

/**
 * AES-GCM Authentication/Integrity + Encryption/Ciphering Algorithm with 16-octet ICV
 * (truncation).
 */

public static final int ENCRYPTION_ALGORITHM_AES_GCM_16 = 20; // 0x14

/**
 * AES-GCM Authentication/Integrity + Encryption/Ciphering Algorithm with 8-octet ICV
 * (truncation).
 */

public static final int ENCRYPTION_ALGORITHM_AES_GCM_8 = 18; // 0x12

/**
 * ChaCha20-Poly1305 Authentication/Integrity + Encryption/Ciphering Algorithm with 16-octet ICV
 * (truncation).
 */

public static final int ENCRYPTION_ALGORITHM_CHACHA20_POLY1305 = 28; // 0x1c

/** AES-CMAC-96 Authentication/Integrity Algorithm. */

public static final int INTEGRITY_ALGORITHM_AES_CMAC_96 = 8; // 0x8

/** AES-XCBC-96 Authentication/Integrity Algorithm. */

public static final int INTEGRITY_ALGORITHM_AES_XCBC_96 = 5; // 0x5

/** HMAC-SHA1 Authentication/Integrity Algorithm. */

public static final int INTEGRITY_ALGORITHM_HMAC_SHA1_96 = 2; // 0x2

/** HMAC-SHA256 Authentication/Integrity Algorithm with 128-bit truncation. */

public static final int INTEGRITY_ALGORITHM_HMAC_SHA2_256_128 = 12; // 0xc

/** HMAC-SHA384 Authentication/Integrity Algorithm with 192-bit truncation. */

public static final int INTEGRITY_ALGORITHM_HMAC_SHA2_384_192 = 13; // 0xd

/** HMAC-SHA512 Authentication/Integrity Algorithm with 256-bit truncation. */

public static final int INTEGRITY_ALGORITHM_HMAC_SHA2_512_256 = 14; // 0xe

/** None Authentication/Integrity Algorithm. */

public static final int INTEGRITY_ALGORITHM_NONE = 0; // 0x0

/** AES Encryption/Ciphering Algorithm key length 128 bits. */

public static final int KEY_LEN_AES_128 = 128; // 0x80

/** AES Encryption/Ciphering Algorithm key length 192 bits. */

public static final int KEY_LEN_AES_192 = 192; // 0xc0

/** AES Encryption/Ciphering Algorithm key length 256 bits. */

public static final int KEY_LEN_AES_256 = 256; // 0x100

/**
 * Key length unused.
 *
 * <p>This value should only be used with the Encryption/Ciphering Algorithm that accepts a
 * fixed key size such as {@link #ENCRYPTION_ALGORITHM_3DES}.
 */

public static final int KEY_LEN_UNUSED = 0; // 0x0

/** AES128-CMAC Pseudorandom Function. */

public static final int PSEUDORANDOM_FUNCTION_AES128_CMAC = 8; // 0x8

/** AES128-XCBC Pseudorandom Function. */

public static final int PSEUDORANDOM_FUNCTION_AES128_XCBC = 4; // 0x4

/** HMAC-SHA1 Pseudorandom Function. */

public static final int PSEUDORANDOM_FUNCTION_HMAC_SHA1 = 2; // 0x2

/** HMAC-SHA2-256 Pseudorandom Function. */

public static final int PSEUDORANDOM_FUNCTION_SHA2_256 = 5; // 0x5

/** HMAC-SHA2-384 Pseudorandom Function. */

public static final int PSEUDORANDOM_FUNCTION_SHA2_384 = 6; // 0x6

/** HMAC-SHA2-384 Pseudorandom Function. */

public static final int PSEUDORANDOM_FUNCTION_SHA2_512 = 7; // 0x7
}

